# coding: utf-8

import requests
import re

from .exceptions import BadResponse
from .utils import check_status_code, cleanup_phone_number


def get_balance(number, password):
    s = requests.Session()
    # API expects phone number in strict international format
    # Only digits: <COUNTRY_CODE><ABC/DEF><PHONE_NUMBER>
    number = cleanup_phone_number(number)

    data = {"client_id": "digital-suite-web-app",
            "grant_type": "password",
            "username": number,
            "password": password,
            "password_type": "password",
            }
    response = s.post('https://my.tele2.ru/auth/realms/tele2-b2c/protocol/openid-connect/token', data=data)

    if not response.ok:
        print(response, response.content)
        raise ValueError('Authentication Failed')

    token = response.json()['access_token']
    s.headers.update({'Authorization': 'Bearer {}'.format(token)})

    response = s.get('https://my.tele2.ru/api/subscribers/{}/balance'.format(number))
    check_status_code(response, 200)

    amount = response.json().get('data', {}).get('value', None)
    if amount is None:
        raise BadResponse('Unable to get balance amount from JSON', response)

    return amount



#!/usr/bin/env python
# coding: utf-8

import requests
import re

from .exceptions import BadResponse
from .utils import check_status_code


LOGIN_ENDPOINT = "http://login.mts.ru/amserver/UI/Login"


def get_balance(number, password):
    session = requests.Session()

    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:81.0) Gecko/20100101 Firefox/81.0",
    }

    response = session.get(LOGIN_ENDPOINT, headers=headers)
    check_status_code(response, 200)

    csrf_token, csrf_ts_token = get_tokens(response)

    headers["Referer"] = LOGIN_ENDPOINT

    response = session.post(
        LOGIN_ENDPOINT,
        data={
            "IDToken1": number,
            "IDButton": "Submit",
            "encoded": "false",
            "loginURL": "?service=default",
            "csrf.sign": csrf_token,
            "csrf.ts": csrf_ts_token,
        },
        headers=headers,
    )
    check_status_code(response, 200)

    csrf_token, csrf_ts_token = get_tokens(response)

    response = session.post(
        LOGIN_ENDPOINT,
        data={
            "IDToken1": number,
            "IDToken2": password,
            "IDButton": "Check",
            "encoded": "false",
            "loginURL": "?service=default",
            "csrf.sign": csrf_token,
            "csrf.ts": csrf_ts_token,
        },
        headers=headers,
        allow_redirects=False,
    )
    check_status_code(response, 200)

    csrf_token, csrf_ts_token = get_tokens(response)

    response = session.post(
        LOGIN_ENDPOINT,
        data={
            "IDButton": "Login",
            "encoded": "false",
            "csrf.sign": csrf_token,
            "csrf.ts": csrf_ts_token,
        },
        headers=headers,
        allow_redirects=False,
    )
    check_status_code(response, 302)

    response = session.get("https://login.mts.ru/amserver/api/profile")
    check_status_code(response, 200)

    data = response.json()
    balance = data["mobile:balance"]

    if balance is None:
        raise BadResponse("Unable to get balance from JSON", response)

    return float(balance)


def get_tokens(response):
    csrf_token = re.search(r'name="csrf.sign" value="(.*?)"', response.text)
    csrf_ts_token = re.search(
        r'name="csrf.ts" value="(.*?)"', response.text
    )

    if csrf_token is None:
        raise BadResponse("CSRF token not found", response)

    return csrf_token.group(1), csrf_ts_token.group(1)



# coding: utf-8

import requests
import re
import time

from .exceptions import BadResponse
from .utils import check_status_code

from bs4 import BeautifulSoup

def get_balance(number, password):
    s = requests.Session()

    # https://szf.b2blk.megafon.ru currently has an issue with its certificates chain
    response = s.get('https://szf.b2blk.megafon.ru/b2b/login', verify=False)

    check_status_code(response, 200)

    millis = int(round(time.time() * 1000))

    response = s.post('https://szf.b2blk.megafon.ru/b2b/loginProcess',
                      data={'username': number,
                            'password': password,
                            'captchaTime': millis,
                        })
    check_status_code(response, 200)

    soup = BeautifulSoup(response.text)
    data = soup.findAll('span', {'class': 'money bold'})
    return data[0].get_text()



# coding: utf-8

import requests
import re

from .exceptions import BadResponse
from .utils import check_status_code


def get_balance(number, password):
    s = requests.Session()
    try:
        response = s.get('https://lk.megafon.ru/login/')
        check_status_code(response, 200)
    except:
        print('Unable to get the data from Megafon site. Exiting!')
        exit(1)
    
        # Replaced the cookie search
    try:
        csrf_token = response.cookies['CSRF-TOKEN']
    except:
        print('Unable to get the Megafon auth token. Exiting!')
        exit(1)


    if csrf_token is None:
        raise BadResponse('CSRF token not found', response)
    try:
        response = s.post('https://lk.megafon.ru/dologin/',
                        data={'j_username': number,
                                'j_password': password,
                                'CSRF': csrf_token,
                            })
        check_status_code(response, 200)
    except: 
        raise BadResponse('Unable to login the Megafon site. Exiting!', response)
    
    if u'Символы с картинки' in response.text:
        raise BadResponse('CAPTCHA was shown', response)
    if u'Требуется ввод цифрового кода' in response.text:
        raise BadResponse('CAPTCHA was shown', response)
    if u'Как получить пароль' in response.text:
        raise BadResponse('Bad password or login', response)
    
    try:
        response = s.get('https://lk.megafon.ru/api/lk/balance/get')

        check_status_code(response, 200)
    
    except: 
        raise BadResponse('Unable to get Megafon balance', response)
    data = response.json()

    if 'balance' not in data:
        raise BadResponse('Unable to get Megafon balance', response)
    return data['balance']




import re

from .exceptions import BadResponse


def check_status_code(response, expected_code):
    result_code = response.status_code

    if result_code != expected_code:
        url = response.url
        method = response.request.method

        raise BadResponse(('{method} to {url} resulted '
                           'in {result_code} status code '
                           'instead of {expected_code}').format(
            **locals()),
            response)


def cleanup_phone_number(number):
    number_clean = re.sub(r'\D', '', number)
    if len(number_clean) == 11 and number_clean[0] != '7':
        number_clean = '7{}' + number_clean[1:]
    elif len(number_clean) == 10:
        number_clean = '7{}' + number_clean
    if not re.match(r'^7\d{10}$', number_clean):
        raise ValueError('Incorrect phone number format. Must be 7XXXXXXXXXX')
    return number_clean



#!/usr/bin/env python
# coding: utf-8

from uuid import uuid4
import requests

from .exceptions import BadResponse
from .utils import check_status_code


def is_json_has_path(json, path):
    current_element = json
    for path_element in path:
        if not current_element.get(path_element):
            return False
        else:
            current_element = current_element[path_element]
    return True


def generate_client_id():
    return "mybee%3B{}%3Bandroid_22%3B4.26.1_965".format(uuid4())


def get_balance(number, password):
    session = requests.Session()
    token_response = session.get(
        "http://api.beeline.ru/mw/auth/1/auth",
        params={
            "client_id": generate_client_id(),
            "login": number,
            "password": password,
        },
    )
    check_status_code(token_response, 200)
    if not token_response.json().get("token"):
        raise BadResponse("Token not found", token_response)
    token = token_response.json()["token"]

    balance_response = session.get(
        "https://api.beeline.ru/mobile/api/v1/dynamic/data",
        params={"blocks": "Profile_Balance"},
        headers={"X-Auth-Token": token, "X-Login": number, "X-CTN": number},
    )
    check_status_code(balance_response, 200)
    if not is_json_has_path(
        balance_response.json(), ["data", "profile_Balance", "balance", "value"]
    ):
        raise BadResponse("Incorrect balance response", balance_response)
    return balance_response.json()["data"]["profile_Balance"]["balance"]["value"]
